"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCodeDisplayedOutput = void 0;
const Debug = require("debug");
const chalk_1 = require("chalk");
const debug = Debug('code-output');
function getCodeDisplayedOutput(codeTest, meta, prefix) {
    let issues = {
        low: [],
        medium: [],
        high: [],
    };
    if (codeTest.runs[0].results) {
        const results = codeTest.runs[0].results;
        const rulesMap = getRulesMap(codeTest.runs[0].tool.driver.rules || []);
        issues = results.reduce((acc, res) => {
            var _a;
            if ((_a = res.locations) === null || _a === void 0 ? void 0 : _a.length) {
                const location = res.locations[0].physicalLocation;
                if (res.level && (location === null || location === void 0 ? void 0 : location.artifactLocation) && (location === null || location === void 0 ? void 0 : location.region)) {
                    const severity = sarifToSeverityLevel(res.level);
                    const ruleId = res.ruleId;
                    if (!(ruleId in rulesMap)) {
                        debug('Rule ID does not exist in the rules list');
                    }
                    const ruleName = rulesMap[ruleId].name;
                    const ruleIdSeverityText = severitiesColourMapping[severity].colorFunc(` ✗ [${severity}] ${ruleName}`);
                    const artifactLocationUri = location.artifactLocation.uri;
                    const startLine = location.region.startLine;
                    const markdown = res.message.markdown;
                    const title = ruleIdSeverityText;
                    const path = `    Path: ${artifactLocationUri}, line ${startLine}`;
                    const info = `    Info: ${markdown}`;
                    acc[severity.toLowerCase()].push(`${title} \n ${path} \n ${info}\n\n`);
                }
            }
            return acc;
        }, issues);
    }
    const issuesText = issues.low.join('') + issues.medium.join('') + issues.high.join('');
    const lowSeverityText = issues.low.length
        ? severitiesColourMapping.Low.colorFunc(` ${issues.low.length} [Low] `)
        : '';
    const mediumSeverityText = issues.medium.length
        ? severitiesColourMapping.Medium.colorFunc(` ${issues.medium.length} [Medium] `)
        : '';
    const highSeverityText = issues.high.length
        ? severitiesColourMapping.High.colorFunc(`${issues.high.length} [High] `)
        : '';
    const vulnPathsText = chalk_1.default.green('✔ Awesome! No issues were found.');
    const summaryOKText = chalk_1.default.green('✓ Test completed');
    const codeIssueCount = issues.low.length + issues.medium.length + issues.high.length;
    const codeIssueFound = `${codeIssueCount} Code issue${codeIssueCount > 0 ? 's' : ''} found`;
    const issuesBySeverityText = highSeverityText + mediumSeverityText + lowSeverityText;
    const codeIssue = codeIssueCount > 0
        ? codeIssueFound + '\n' + issuesBySeverityText
        : vulnPathsText;
    return (prefix +
        issuesText +
        '\n' +
        summaryOKText +
        '\n\n' +
        meta +
        '\n\n' +
        codeIssue);
}
exports.getCodeDisplayedOutput = getCodeDisplayedOutput;
function getRulesMap(rules) {
    const rulesMapByID = rules.reduce((acc, rule) => {
        acc[rule.id] = rule;
        return acc;
    }, {});
    return rulesMapByID;
}
function sarifToSeverityLevel(sarifConfigurationLevel) {
    const severityLevel = {
        note: 'Low',
        warning: 'Medium',
        error: 'High',
    };
    return severityLevel[sarifConfigurationLevel];
}
const severitiesColourMapping = {
    Low: {
        colorFunc(text) {
            return chalk_1.default.blueBright(text);
        },
    },
    Medium: {
        colorFunc(text) {
            return chalk_1.default.yellowBright(text);
        },
    },
    High: {
        colorFunc(text) {
            return chalk_1.default.redBright(text);
        },
    },
};
//# sourceMappingURL=code-output.js.map